@@ -14,12 +14,12 @@ urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
 class Downloader(object):
     def __init__(self, path, url, name, postfix):
+        self.lg = Logger()
         self._path = path
         self._url = url
         self._name = name
         self._max_retry = 3
         self.postfix = postfix
-        self.logger = Logger()
         self.time = Time()
         self.time.set_fmt('%H:%M:%S')
         if not os.path.exists(path):
@@ -44,6 +44,27 @@ class Downloader(object):
     def max_retry(self):
         return self._max_retry
 
+    def run(self):
+        max_retry_count = self.max_retry
+        retry_count = 0
+        while retry_count < max_retry_count:
+            try:
+                self.start_download()
+                break
+            except Exception as Ex:
+                self.lg.error()
+                retry_count += 1
+
+        if retry_count >= max_retry_count:
+            resp = requests.get(self._url)
+            if resp.status_code != 404:
+                time.sleep(60)
+                try:
+                    self.start_download()
+                except:
+                    self.lg.error()
+            self.lg.warning("Download failed|{}".format(resp.status_code))
+
     def start_download(self):
         # deal with file type
         if self.postfix == 'video':
@@ -62,7 +83,7 @@ class Downloader(object):
 
         if os.path.exists(file_path):
             file_size = os.path.getsize(file_path)
-            self.logger.info("File downloaded|{:.2f}MB|{}|{}".format(file_size / (1024 * 1024), self._name, self._url))
+            self.lg.info("File downloaded|{:.2f}MB|{}|{}".format(file_size / (1024 * 1024), self._name, self._url))
             return
 
         with requests.session() as req:
@@ -85,26 +106,26 @@ class Downloader(object):
                 total_length = int(content_length_s)
             else:
                 total_length = None
-                self.logger.warning('Content-Lenght is null|{}|{} |{}'.format(self._name, self._url, resp.status_code))
+                self.lg.warning('Content-Lenght is null|{}|{} |{}'.format(self._name, self._url, resp.status_code))
                 return
 
             content_offset = 0
             if os.path.exists(_file_path):
                 content_offset = os.path.getsize(_file_path)
-                self.logger.info(
+                self.lg.info(
                     'Continue to download|{:.2f}MB/{:.2f}MB|{}|{}'.format(content_offset / (1024 * 1024),
                                                                           total_length / (1024 * 1024), self._name,
                                                                           self._url)
                 )
             else:
-                self.logger.info(
+                self.lg.info(
                     "Start to download|{:.2f}MB|{}|{}".format(total_length / (1024 * 1024), self._name, self._url))
 
             # =================================================== second request with head to download the remain data
             req.headers = {'Range': "bytes=%d-%d" % (content_offset, content_offset + total_length)}
             resp = req.get(self._url)
             size = content_offset
-            fmt = self.logger.fmt
+            fmt = self.lg.fmt
             pre_module = sys._getframe(1).f_code.co_filename.split('/')[-1].split('.')[0]
             with open(_file_path, 'ab') as file:
                 progress_bar_length = 30
@@ -112,14 +133,6 @@ class Downloader(object):
                     file.write(data)
                     size += len(data)
                     done = int(progress_bar_length * size / total_length)
-                    # sys.stdout.write(
-                    #     "\r[{}{}] [{:.2f}MB] [{:.2f}MB] [{}] [{}]".format('=' * done, ' ' * (progress_bar_length - done),
-                    #                                                  size / (1024 * 1024),
-                    #                                                  total_length / (1024 * 1024),
-                    #                                                  self._name,
-                    #                                                  self._url,
-                    #                                                  # str(round(float(size / total_length) * 100, 2)), # %
-                    #                                                  ))
                     sys.stdout.write(
                         fmt.format(self.time.get_fmt_time, pre_module, '\033[1;32mINFO\033[0m',
                                    "[{}{}] [{:.2f}MB] [{:.2f}MB] [{}] [{}]".format('=' * done,
@@ -134,23 +147,9 @@ class Downloader(object):
                     file.flush()
             os.rename(_file_path, file_path)
             end = time.time()
-            self.logger.info(
-                "Download successfully|{:.2f}S|{:.2f}MB|{}|{}".format(end - start, total_length / (1024 * 1024), self._name, self._url))
-
-    def run(self):
-        max_retry_count = self.max_retry
-        retry_count = 0
-        while retry_count < max_retry_count:
-            try:
-                self.start_download()
-                break
-            except Exception as Ex:
-                self.logger.error()
-                retry_count += 1
-
-        if retry_count >= max_retry_count:
-            resp = req.get(self._url)
-            self.logger.warning("Download failed|{}".format(resp.status_code))
+            self.lg.info(
+                "Download successfully|{:.2f}S|{:.2f}MB|{}|{}".format(end - start, total_length / (1024 * 1024),
+                                                                      self._name, self._url))
 
     @path.setter
     def path(self, value):
@@ -174,21 +173,23 @@ class Download_from_file(object):
         self.file_path = file_path
         self.save_path = save_path
         self.info = info
+        self.selector = {'txt': symbol, 'csv': ','}
 
     @property
-    def download_project_list(self):
+    def downloader_list(self):
         project_list = []
-        with open('dld.txt', 'r') as f:
+        symbol = self.selector(self.file_path.split('.')[-1])
+        with open(self.file_path, 'r') as f:
             for i in f:
-                num = len(i.split('|'))
+                num = len(i.split(symbol))
                 if num == 3:
-                    url = i.split('|')[1]
-                    name = i.split('|')[2]
+                    url = i.split(symbol)[1]
+                    name = i.split(symbol)[2]
                     d = Downloader(self.save_path, url, name, 'mp4')
                     project_list.append(d)
                 elif num == 2:
-                    url = i.split('|')[0]
-                    name = i.split('|')[1]
+                    url = i.split(symbol)[0]
+                    name = i.split(symbol)[1]
                     d = Downloader(self.save_path, url, name, 'mp4')
                     project_list.append(d)
         return project_list
@@ -198,5 +199,6 @@ class Download_from_file(object):
 
     def start(self, max_thread=10):
         t_pool = ThreadPool(max_thread, info=self.info)
-        t_pool.add_task_list(self.run, self.download_project_list)
+        key = self.file_path.split(".")[-1]
+        t_pool.add_task_list(self.run, self.downloader_list)
         t_pool.run()
