@@ -14,26 +14,15 @@ urllib3.disable_warnings()
 
 
 class WebC(object):
-    ua = UserAgent()
-    headers = {
-        'User-Agent': ua.random
-    }
-
     def __init__(self, url=None, headers=None, cookies={}, timeout=30):
         from fake_useragent import UserAgent
-        self._ua = UserAgent()
         self._url = url
         self._save = False
         self._encode = 'utf-8'
         self._response = None
         self._cookies = cookies
         self._timeout = timeout
-        if not headers:
-            self._headers = {
-                'User-Agent': self._ua.random
-            }
-        else:
-            self._headers = headers
+        self._headers = headers
         if cookies:
             self.cookies = cookies
 
@@ -124,6 +113,3 @@ class WebC(object):
         ct = resp.content
         json_dict = json.loads(ct)
         return json_dict
-
-
-
